@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Cpanel::JSON::XS qw( decode_json encode_json );
 use HTTP::Request;
@@ -21,10 +21,9 @@ has token => (
 );
 
 has base_uri => (
-    is      => 'ro',
-    isa     => Uri,
-    coerce  => 1,
-    default => 'https://www.pivotaltracker.com/services/v5/',
+    is       => 'ro',
+    isa      => Uri,
+    required => 1,
 );
 
 has _ua => (
