@@ -3,7 +3,7 @@ package WebService::PivotalTracker::PropertyAttributes;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Scalar::Util qw( blessed );
 use Sub::Quote qw( quote_sub );
@@ -32,7 +32,7 @@ sub _attr_for {
     my %env;
     if ( $prop->{may_require_refresh} ) {
         $default .= sprintf( <<'EOF', $name );
-$_[0]->_refresh_raw_content unless exists $_[0]->raw_content(%s);
+$_[0]->_refresh_raw_content unless exists $_[0]->raw_content->{%s};
 EOF
     }
 
